/******************************************************************************/
/*            TEXAS INSTRUMENTS INCORPORATED PROPRIETARY INFORMATION          */ 
/*   Created 2005, (C) Copyright 2005 Texas Instruments.  All rights reserved.*/ 
/*																			  */
/* 	FILE	: cslr_emif_001.h 				                          	 	  */
/*  PROJECT	: DaVinci ROM boot-loader 		                                  */
/*  AUTHOR	: Vignesh LA					                                  */
/*  DATE	: April-25-2005                                                   */
/******************************************************************************/

#ifndef _CSLR_EMIF_001_H_
#define _CSLR_EMIF_001_H_

#include <tistdtypes.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 ERCSR;
    volatile Uint32 AWCCR;
    volatile Uint32 SDBCR;
    volatile Uint32 SDRCR;
    volatile Uint32 AB1CR;
    volatile Uint32 AB2CR;
    volatile Uint32 AB3CR;
    volatile Uint32 AB4CR;
    volatile Uint32 SDTIMR;
    volatile Uint32 DDRSR;
    volatile Uint32 DDRPHYCR;
    volatile Uint32 DDRPHYSR;
    volatile Uint32 TOTAR;
    volatile Uint32 TOTACTR;
    volatile Uint32 DDRPHYID_REV;
    volatile Uint32 SDSRETR;
    volatile Uint32 EIRR;
    volatile Uint32 EIMR;
    volatile Uint32 EIMSR;
    volatile Uint32 EIMCR;
    volatile Uint32 IOCTRLR;
    volatile Uint32 IOSTATR;
    volatile Uint8 RSVD0[8];
    volatile Uint32 NANDFCR;
    volatile Uint32 NANDFSR;
    volatile Uint8 RSVD1[8];
    volatile Uint32 NANDF1ECC;
    volatile Uint32 NANDF2ECC;
    volatile Uint32 NANDF3ECC;
    volatile Uint32 NANDF4ECC;
    volatile Uint8 RSVD2[4];
    volatile Uint32 IODFTECR;
    volatile Uint32 IODFTGCR;
    volatile Uint8 RSVD3[4];
    volatile Uint32 IODFTMRLR;
    volatile Uint32 IODFTMRMR;
    volatile Uint32 IODFTMRMSBR;
    volatile Uint8 RSVD4[20];
    volatile Uint32 MODRNR;
} CSL_EmifRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* ERCSR */

#define CSL_EMIF_ERCSR_BE_MASK           (0x80000000u)
#define CSL_EMIF_ERCSR_BE_SHIFT          (0x0000001Fu)
#define CSL_EMIF_ERCSR_BE_RESETVAL       (0x00000001u)

#define CSL_EMIF_ERCSR_FR_MASK           (0x40000000u)
#define CSL_EMIF_ERCSR_FR_SHIFT          (0x0000001Eu)
#define CSL_EMIF_ERCSR_FR_RESETVAL       (0x00000001u)

#define CSL_EMIF_ERCSR_MID_MASK          (0x3FFF0000u)
#define CSL_EMIF_ERCSR_MID_SHIFT         (0x00000010u)
#define CSL_EMIF_ERCSR_MID_RESETVAL      (0x00000000u)

#define CSL_EMIF_ERCSR_MAJREV_MASK       (0x0000FF00u)
#define CSL_EMIF_ERCSR_MAJREV_SHIFT      (0x00000008u)
#define CSL_EMIF_ERCSR_MAJREV_RESETVAL   (0x00000002u)

#define CSL_EMIF_ERCSR_MINREV_MASK       (0x000000FFu)
#define CSL_EMIF_ERCSR_MINREV_SHIFT      (0x00000000u)
#define CSL_EMIF_ERCSR_MINREV_RESETVAL   (0x00000001u)

#define CSL_EMIF_ERCSR_RESETVAL          (0xC0000201u)

/* AWCCR */

#define CSL_EMIF_AWCCR_WP3_MASK          (0x80000000u)
#define CSL_EMIF_AWCCR_WP3_SHIFT         (0x0000001Fu)
#define CSL_EMIF_AWCCR_WP3_RESETVAL      (0x00000001u)

/*----WP3 Tokens----*/
#define CSL_EMIF_AWCCR_WP3_WAITLOW       (0x00000000u)
#define CSL_EMIF_AWCCR_WP3_WAITHIGH      (0x00000001u)

#define CSL_EMIF_AWCCR_WP2_MASK          (0x40000000u)
#define CSL_EMIF_AWCCR_WP2_SHIFT         (0x0000001Eu)
#define CSL_EMIF_AWCCR_WP2_RESETVAL      (0x00000001u)

/*----WP2 Tokens----*/
#define CSL_EMIF_AWCCR_WP2_WAITLOW       (0x00000000u)
#define CSL_EMIF_AWCCR_WP2_WAITHIGH      (0x00000001u)

#define CSL_EMIF_AWCCR_WP1_MASK          (0x20000000u)
#define CSL_EMIF_AWCCR_WP1_SHIFT         (0x0000001Du)
#define CSL_EMIF_AWCCR_WP1_RESETVAL      (0x00000001u)

/*----WP1 Tokens----*/
#define CSL_EMIF_AWCCR_WP1_WAITLOW       (0x00000000u)
#define CSL_EMIF_AWCCR_WP1_WAITHIGH      (0x00000001u)

#define CSL_EMIF_AWCCR_WP0_MASK          (0x10000000u)
#define CSL_EMIF_AWCCR_WP0_SHIFT         (0x0000001Cu)
#define CSL_EMIF_AWCCR_WP0_RESETVAL      (0x00000001u)

/*----WP0 Tokens----*/
#define CSL_EMIF_AWCCR_WP0_WAITLOW       (0x00000000u)
#define CSL_EMIF_AWCCR_WP0_WAITHIGH      (0x00000001u)

#define CSL_EMIF_AWCCR_CS3WAIT_MASK      (0x00C00000u)
#define CSL_EMIF_AWCCR_CS3WAIT_SHIFT     (0x00000016u)
#define CSL_EMIF_AWCCR_CS3WAIT_RESETVAL  (0x00000000u)

#define CSL_EMIF_AWCCR_CS2WAIT_MASK      (0x00300000u)
#define CSL_EMIF_AWCCR_CS2WAIT_SHIFT     (0x00000014u)
#define CSL_EMIF_AWCCR_CS2WAIT_RESETVAL  (0x00000000u)

#define CSL_EMIF_AWCCR_CS1WAIT_MASK      (0x000C0000u)
#define CSL_EMIF_AWCCR_CS1WAIT_SHIFT     (0x00000012u)
#define CSL_EMIF_AWCCR_CS1WAIT_RESETVAL  (0x00000000u)

#define CSL_EMIF_AWCCR_CS0WAIT_MASK      (0x00030000u)
#define CSL_EMIF_AWCCR_CS0WAIT_SHIFT     (0x00000010u)
#define CSL_EMIF_AWCCR_CS0WAIT_RESETVAL  (0x00000000u)

#define CSL_EMIF_AWCCR_MEWC_MASK         (0x000000FFu)
#define CSL_EMIF_AWCCR_MEWC_SHIFT        (0x00000000u)
#define CSL_EMIF_AWCCR_MEWC_RESETVAL     (0x00000080u)

#define CSL_EMIF_AWCCR_RESETVAL          (0xF0000080u)

/* SDBCR */

#define CSL_EMIF_SDBCR_SR_MASK           (0x80000000u)
#define CSL_EMIF_SDBCR_SR_SHIFT          (0x0000001Fu)
#define CSL_EMIF_SDBCR_SR_RESETVAL       (0x00000000u)

#define CSL_EMIF_SDBCR_PD_MASK           (0x40000000u)
#define CSL_EMIF_SDBCR_PD_SHIFT          (0x0000001Eu)
#define CSL_EMIF_SDBCR_PD_RESETVAL       (0x00000000u)

#define CSL_EMIF_SDBCR_PDWR_MASK         (0x20000000u)
#define CSL_EMIF_SDBCR_PDWR_SHIFT        (0x0000001Du)
#define CSL_EMIF_SDBCR_PDWR_RESETVAL     (0x00000000u)

#define CSL_EMIF_SDBCR_DDRDRST_MASK      (0x00020000u)
#define CSL_EMIF_SDBCR_DDRDRST_SHIFT     (0x00000011u)
#define CSL_EMIF_SDBCR_DDRDRST_RESETVAL  (0x00000000u)

#define CSL_EMIF_SDBCR_BIT17LOCK_MASK    (0x00010000u)
#define CSL_EMIF_SDBCR_BIT17LOCK_SHIFT   (0x00000010u)
#define CSL_EMIF_SDBCR_BIT17LOCK_RESETVAL (0x00000000u)

#define CSL_EMIF_SDBCR_NM_MASK           (0x00004000u)
#define CSL_EMIF_SDBCR_NM_SHIFT          (0x0000000Eu)
#define CSL_EMIF_SDBCR_NM_RESETVAL       (0x00000000u)

#define CSL_EMIF_SDBCR_DISDDRDLL_MASK    (0x00002000u)
#define CSL_EMIF_SDBCR_DISDDRDLL_SHIFT   (0x0000000Du)
#define CSL_EMIF_SDBCR_DISDDRDLL_RESETVAL (0x00000001u)

#define CSL_EMIF_SDBCR_BIT13LOCK_MASK    (0x00001000u)
#define CSL_EMIF_SDBCR_BIT13LOCK_SHIFT   (0x0000000Cu)
#define CSL_EMIF_SDBCR_BIT13LOCK_RESETVAL (0x00000000u)

#define CSL_EMIF_SDBCR_CL_MASK           (0x00000E00u)
#define CSL_EMIF_SDBCR_CL_SHIFT          (0x00000009u)
#define CSL_EMIF_SDBCR_CL_RESETVAL       (0x00000003u)

/*----CL Tokens----*/
#define CSL_EMIF_SDBCR_CL_CASLAT2        (0x00000002u)

#define CSL_EMIF_SDBCR_BIT11_9LOCK_MASK  (0x00000100u)
#define CSL_EMIF_SDBCR_BIT11_9LOCK_SHIFT (0x00000008u)
#define CSL_EMIF_SDBCR_BIT11_9LOCK_RESETVAL (0x00000000u)

#define CSL_EMIF_SDBCR_IBANK_MASK        (0x00000070u)
#define CSL_EMIF_SDBCR_IBANK_SHIFT       (0x00000004u)
#define CSL_EMIF_SDBCR_IBANK_RESETVAL    (0x00000002u)

/*----IBANK Tokens----*/
#define CSL_EMIF_SDBCR_IBANK_SD1BANK     (0x00000000u)

#define CSL_EMIF_SDBCR_EBANK_MASK        (0x00000008u)
#define CSL_EMIF_SDBCR_EBANK_SHIFT       (0x00000003u)
#define CSL_EMIF_SDBCR_EBANK_RESETVAL    (0x00000000u)

#define CSL_EMIF_SDBCR_PAGESIZE_MASK     (0x00000007u)
#define CSL_EMIF_SDBCR_PAGESIZE_SHIFT    (0x00000000u)
#define CSL_EMIF_SDBCR_PAGESIZE_RESETVAL (0x00000000u)

#define CSL_EMIF_SDBCR_RESETVAL          (0x00002620u)

/* SDRCR */

#define CSL_EMIF_SDRCR_DDRRT_MASK        (0x00070000u)
#define CSL_EMIF_SDRCR_DDRRT_SHIFT       (0x00000010u)
#define CSL_EMIF_SDRCR_DDRRT_RESETVAL    (0x00000000u)

#define CSL_EMIF_SDRCR_RR_MASK           (0x00001FFFu)
#define CSL_EMIF_SDRCR_RR_SHIFT          (0x00000000u)
#define CSL_EMIF_SDRCR_RR_RESETVAL       (0x00000010u)

#define CSL_EMIF_SDRCR_RESETVAL          (0x00000010u)

/* AB1CR */

#define CSL_EMIF_AB1CR_SS_MASK           (0x80000000u)
#define CSL_EMIF_AB1CR_SS_SHIFT          (0x0000001Fu)
#define CSL_EMIF_AB1CR_SS_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB1CR_EW_MASK           (0x40000000u)
#define CSL_EMIF_AB1CR_EW_SHIFT          (0x0000001Eu)
#define CSL_EMIF_AB1CR_EW_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB1CR_W_SETUP_MASK      (0x3C000000u)
#define CSL_EMIF_AB1CR_W_SETUP_SHIFT     (0x0000001Au)
#define CSL_EMIF_AB1CR_W_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB1CR_W_STROBE_MASK     (0x03F00000u)
#define CSL_EMIF_AB1CR_W_STROBE_SHIFT    (0x00000014u)
#define CSL_EMIF_AB1CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB1CR_W_HOLD_MASK       (0x000E0000u)
#define CSL_EMIF_AB1CR_W_HOLD_SHIFT      (0x00000011u)
#define CSL_EMIF_AB1CR_W_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB1CR_R_SETUP_MASK      (0x0001E000u)
#define CSL_EMIF_AB1CR_R_SETUP_SHIFT     (0x0000000Du)
#define CSL_EMIF_AB1CR_R_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB1CR_R_STROBE_MASK     (0x00001F80u)
#define CSL_EMIF_AB1CR_R_STROBE_SHIFT    (0x00000007u)
#define CSL_EMIF_AB1CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB1CR_R_HOLD_MASK       (0x00000070u)
#define CSL_EMIF_AB1CR_R_HOLD_SHIFT      (0x00000004u)
#define CSL_EMIF_AB1CR_R_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB1CR_TA_MASK           (0x0000000Cu)
#define CSL_EMIF_AB1CR_TA_SHIFT          (0x00000002u)
#define CSL_EMIF_AB1CR_TA_RESETVAL       (0x00000003u)

#define CSL_EMIF_AB1CR_ASIZE_MASK        (0x00000003u)
#define CSL_EMIF_AB1CR_ASIZE_SHIFT       (0x00000000u)
#define CSL_EMIF_AB1CR_ASIZE_RESETVAL    (0x00000001u)

/*----ASIZE Tokens----*/
#define CSL_EMIF_AB1CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF_AB1CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF_AB1CR_RESETVAL          (0x3FFFFFFDu)

/* AB2CR */

#define CSL_EMIF_AB2CR_SS_MASK           (0x80000000u)
#define CSL_EMIF_AB2CR_SS_SHIFT          (0x0000001Fu)
#define CSL_EMIF_AB2CR_SS_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB2CR_EW_MASK           (0x40000000u)
#define CSL_EMIF_AB2CR_EW_SHIFT          (0x0000001Eu)
#define CSL_EMIF_AB2CR_EW_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB2CR_W_SETUP_MASK      (0x3C000000u)
#define CSL_EMIF_AB2CR_W_SETUP_SHIFT     (0x0000001Au)
#define CSL_EMIF_AB2CR_W_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB2CR_W_STROBE_MASK     (0x03F00000u)
#define CSL_EMIF_AB2CR_W_STROBE_SHIFT    (0x00000014u)
#define CSL_EMIF_AB2CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB2CR_W_HOLD_MASK       (0x000E0000u)
#define CSL_EMIF_AB2CR_W_HOLD_SHIFT      (0x00000011u)
#define CSL_EMIF_AB2CR_W_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB2CR_R_SETUP_MASK      (0x0001E000u)
#define CSL_EMIF_AB2CR_R_SETUP_SHIFT     (0x0000000Du)
#define CSL_EMIF_AB2CR_R_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB2CR_R_STROBE_MASK     (0x00001F80u)
#define CSL_EMIF_AB2CR_R_STROBE_SHIFT    (0x00000007u)
#define CSL_EMIF_AB2CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB2CR_R_HOLD_MASK       (0x00000070u)
#define CSL_EMIF_AB2CR_R_HOLD_SHIFT      (0x00000004u)
#define CSL_EMIF_AB2CR_R_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB2CR_TA_MASK           (0x0000000Cu)
#define CSL_EMIF_AB2CR_TA_SHIFT          (0x00000002u)
#define CSL_EMIF_AB2CR_TA_RESETVAL       (0x00000003u)

#define CSL_EMIF_AB2CR_ASIZE_MASK        (0x00000003u)
#define CSL_EMIF_AB2CR_ASIZE_SHIFT       (0x00000000u)
#define CSL_EMIF_AB2CR_ASIZE_RESETVAL    (0x00000001u)

/*----ASIZE Tokens----*/
#define CSL_EMIF_AB2CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF_AB2CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF_AB2CR_RESETVAL          (0x3FFFFFFDu)

/* AB3CR */

#define CSL_EMIF_AB3CR_SS_MASK           (0x80000000u)
#define CSL_EMIF_AB3CR_SS_SHIFT          (0x0000001Fu)
#define CSL_EMIF_AB3CR_SS_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB3CR_EW_MASK           (0x40000000u)
#define CSL_EMIF_AB3CR_EW_SHIFT          (0x0000001Eu)
#define CSL_EMIF_AB3CR_EW_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB3CR_W_SETUP_MASK      (0x3C000000u)
#define CSL_EMIF_AB3CR_W_SETUP_SHIFT     (0x0000001Au)
#define CSL_EMIF_AB3CR_W_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB3CR_W_STROBE_MASK     (0x03F00000u)
#define CSL_EMIF_AB3CR_W_STROBE_SHIFT    (0x00000014u)
#define CSL_EMIF_AB3CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB3CR_W_HOLD_MASK       (0x000E0000u)
#define CSL_EMIF_AB3CR_W_HOLD_SHIFT      (0x00000011u)
#define CSL_EMIF_AB3CR_W_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB3CR_R_SETUP_MASK      (0x0001E000u)
#define CSL_EMIF_AB3CR_R_SETUP_SHIFT     (0x0000000Du)
#define CSL_EMIF_AB3CR_R_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB3CR_R_STROBE_MASK     (0x00001F80u)
#define CSL_EMIF_AB3CR_R_STROBE_SHIFT    (0x00000007u)
#define CSL_EMIF_AB3CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB3CR_R_HOLD_MASK       (0x00000070u)
#define CSL_EMIF_AB3CR_R_HOLD_SHIFT      (0x00000004u)
#define CSL_EMIF_AB3CR_R_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB3CR_TA_MASK           (0x0000000Cu)
#define CSL_EMIF_AB3CR_TA_SHIFT          (0x00000002u)
#define CSL_EMIF_AB3CR_TA_RESETVAL       (0x00000003u)

#define CSL_EMIF_AB3CR_ASIZE_MASK        (0x00000003u)
#define CSL_EMIF_AB3CR_ASIZE_SHIFT       (0x00000000u)
#define CSL_EMIF_AB3CR_ASIZE_RESETVAL    (0x00000001u)

/*----ASIZE Tokens----*/
#define CSL_EMIF_AB3CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF_AB3CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF_AB3CR_RESETVAL          (0x3FFFFFFDu)

/* AB4CR */

#define CSL_EMIF_AB4CR_SS_MASK           (0x80000000u)
#define CSL_EMIF_AB4CR_SS_SHIFT          (0x0000001Fu)
#define CSL_EMIF_AB4CR_SS_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB4CR_EW_MASK           (0x40000000u)
#define CSL_EMIF_AB4CR_EW_SHIFT          (0x0000001Eu)
#define CSL_EMIF_AB4CR_EW_RESETVAL       (0x00000000u)

#define CSL_EMIF_AB4CR_W_SETUP_MASK      (0x3C000000u)
#define CSL_EMIF_AB4CR_W_SETUP_SHIFT     (0x0000001Au)
#define CSL_EMIF_AB4CR_W_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB4CR_W_STROBE_MASK     (0x03F00000u)
#define CSL_EMIF_AB4CR_W_STROBE_SHIFT    (0x00000014u)
#define CSL_EMIF_AB4CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB4CR_W_HOLD_MASK       (0x000E0000u)
#define CSL_EMIF_AB4CR_W_HOLD_SHIFT      (0x00000011u)
#define CSL_EMIF_AB4CR_W_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB4CR_R_SETUP_MASK      (0x0001E000u)
#define CSL_EMIF_AB4CR_R_SETUP_SHIFT     (0x0000000Du)
#define CSL_EMIF_AB4CR_R_SETUP_RESETVAL  (0x0000000Fu)

#define CSL_EMIF_AB4CR_R_STROBE_MASK     (0x00001F80u)
#define CSL_EMIF_AB4CR_R_STROBE_SHIFT    (0x00000007u)
#define CSL_EMIF_AB4CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF_AB4CR_R_HOLD_MASK       (0x00000070u)
#define CSL_EMIF_AB4CR_R_HOLD_SHIFT      (0x00000004u)
#define CSL_EMIF_AB4CR_R_HOLD_RESETVAL   (0x00000007u)

#define CSL_EMIF_AB4CR_TA_MASK           (0x0000000Cu)
#define CSL_EMIF_AB4CR_TA_SHIFT          (0x00000002u)
#define CSL_EMIF_AB4CR_TA_RESETVAL       (0x00000003u)

#define CSL_EMIF_AB4CR_ASIZE_MASK        (0x00000003u)
#define CSL_EMIF_AB4CR_ASIZE_SHIFT       (0x00000000u)
#define CSL_EMIF_AB4CR_ASIZE_RESETVAL    (0x00000001u)

/*----ASIZE Tokens----*/
#define CSL_EMIF_AB4CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF_AB4CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF_AB4CR_RESETVAL          (0x3FFFFFFDu)

/* SDTIMR */

#define CSL_EMIF_SDTIMR_T_RFC_MASK       (0xF8000000u)
#define CSL_EMIF_SDTIMR_T_RFC_SHIFT      (0x0000001Bu)
#define CSL_EMIF_SDTIMR_T_RFC_RESETVAL   (0x00000000u)

#define CSL_EMIF_SDTIMR_T_RP_MASK        (0x07000000u)
#define CSL_EMIF_SDTIMR_T_RP_SHIFT       (0x00000018u)
#define CSL_EMIF_SDTIMR_T_RP_RESETVAL    (0x00000000u)

#define CSL_EMIF_SDTIMR_T_RCD_MASK       (0x00700000u)
#define CSL_EMIF_SDTIMR_T_RCD_SHIFT      (0x00000014u)
#define CSL_EMIF_SDTIMR_T_RCD_RESETVAL   (0x00000000u)

#define CSL_EMIF_SDTIMR_T_WR_MASK        (0x00070000u)
#define CSL_EMIF_SDTIMR_T_WR_SHIFT       (0x00000010u)
#define CSL_EMIF_SDTIMR_T_WR_RESETVAL    (0x00000000u)

#define CSL_EMIF_SDTIMR_T_RAS_MASK       (0x0000F000u)
#define CSL_EMIF_SDTIMR_T_RAS_SHIFT      (0x0000000Cu)
#define CSL_EMIF_SDTIMR_T_RAS_RESETVAL   (0x00000004u)

#define CSL_EMIF_SDTIMR_T_RC_MASK        (0x00000F00u)
#define CSL_EMIF_SDTIMR_T_RC_SHIFT       (0x00000008u)
#define CSL_EMIF_SDTIMR_T_RC_RESETVAL    (0x00000000u)

#define CSL_EMIF_SDTIMR_T_RRD_MASK       (0x00000070u)
#define CSL_EMIF_SDTIMR_T_RRD_SHIFT      (0x00000004u)
#define CSL_EMIF_SDTIMR_T_RRD_RESETVAL   (0x00000000u)

#define CSL_EMIF_SDTIMR_RESETVAL         (0x00004000u)

/* DDRSR */

#define CSL_EMIF_DDRSR_PHYDLLRDY_MASK    (0x00000008u)
#define CSL_EMIF_DDRSR_PHYDLLRDY_SHIFT   (0x00000003u)
#define CSL_EMIF_DDRSR_PHYDLLRDY_RESETVAL (0x00000000u)

#define CSL_EMIF_DDRSR_DDR_MASK          (0x00000001u)
#define CSL_EMIF_DDRSR_DDR_SHIFT         (0x00000000u)
#define CSL_EMIF_DDRSR_DDR_RESETVAL      (0x00000000u)

#define CSL_EMIF_DDRSR_RESETVAL          (0x00000000u)

/* DDRPHYCR */

#define CSL_EMIF_DDRPHYCR_DDRPHYCTRL_MASK (0xFFFFFFFFu)
#define CSL_EMIF_DDRPHYCR_DDRPHYCTRL_SHIFT (0x00000000u)
#define CSL_EMIF_DDRPHYCR_DDRPHYCTRL_RESETVAL (0x00000000u)

#define CSL_EMIF_DDRPHYCR_RESETVAL       (0x00000000u)

/* DDRPHYSR */

#define CSL_EMIF_DDRPHYSR_DDRPHYSTAT_MASK (0xFFFFFFFFu)
#define CSL_EMIF_DDRPHYSR_DDRPHYSTAT_SHIFT (0x00000000u)
#define CSL_EMIF_DDRPHYSR_DDRPHYSTAT_RESETVAL (0x00000000u)

#define CSL_EMIF_DDRPHYSR_RESETVAL       (0x00000000u)

/* TOTAR */

#define CSL_EMIF_TOTAR_TA_MASK           (0xFFFFFFFFu)
#define CSL_EMIF_TOTAR_TA_SHIFT          (0x00000000u)
#define CSL_EMIF_TOTAR_TA_RESETVAL       (0x00000000u)

#define CSL_EMIF_TOTAR_RESETVAL          (0x00000000u)

/* TOTACTR */

#define CSL_EMIF_TOTACTR_TACT_MASK       (0xFFFFFFFFu)
#define CSL_EMIF_TOTACTR_TACT_SHIFT      (0x00000000u)
#define CSL_EMIF_TOTACTR_TACT_RESETVAL   (0x00000000u)

#define CSL_EMIF_TOTACTR_RESETVAL        (0x00000000u)

/* DDRPHYID_REV */

#define CSL_EMIF_DDRPHYID_REV_DDRPHYID_REV_MASK (0xFFFFFFFFu)
#define CSL_EMIF_DDRPHYID_REV_DDRPHYID_REV_SHIFT (0x00000000u)
#define CSL_EMIF_DDRPHYID_REV_DDRPHYID_REV_RESETVAL (0x00000000u)

#define CSL_EMIF_DDRPHYID_REV_RESETVAL   (0x00000000u)

/* SDSRETR */

#define CSL_EMIF_SDSRETR_T_XS_MASK       (0x0000001Fu)
#define CSL_EMIF_SDSRETR_T_XS_SHIFT      (0x00000000u)
#define CSL_EMIF_SDSRETR_T_XS_RESETVAL   (0x00000000u)

#define CSL_EMIF_SDSRETR_RESETVAL        (0x00000000u)

/* EIRR */

#define CSL_EMIF_EIRR_WR_MASK            (0x0000003Cu)
#define CSL_EMIF_EIRR_WR_SHIFT           (0x00000002u)
#define CSL_EMIF_EIRR_WR_RESETVAL        (0x00000000u)

#define CSL_EMIF_EIRR_LT_MASK            (0x00000002u)
#define CSL_EMIF_EIRR_LT_SHIFT           (0x00000001u)
#define CSL_EMIF_EIRR_LT_RESETVAL        (0x00000000u)

#define CSL_EMIF_EIRR_AT_MASK            (0x00000001u)
#define CSL_EMIF_EIRR_AT_SHIFT           (0x00000000u)
#define CSL_EMIF_EIRR_AT_RESETVAL        (0x00000000u)

#define CSL_EMIF_EIRR_RESETVAL           (0x00000000u)

/* EIMR */

#define CSL_EMIF_EIMR_WRM_MASK           (0x0000003Cu)
#define CSL_EMIF_EIMR_WRM_SHIFT          (0x00000002u)
#define CSL_EMIF_EIMR_WRM_RESETVAL       (0x00000000u)

#define CSL_EMIF_EIMR_LTM_MASK           (0x00000002u)
#define CSL_EMIF_EIMR_LTM_SHIFT          (0x00000001u)
#define CSL_EMIF_EIMR_LTM_RESETVAL       (0x00000000u)

#define CSL_EMIF_EIMR_ATM_MASK           (0x00000001u)
#define CSL_EMIF_EIMR_ATM_SHIFT          (0x00000000u)
#define CSL_EMIF_EIMR_ATM_RESETVAL       (0x00000000u)

#define CSL_EMIF_EIMR_RESETVAL           (0x00000000u)

/* EIMSR */

#define CSL_EMIF_EIMSR_WRMSET_MASK       (0x0000003Cu)
#define CSL_EMIF_EIMSR_WRMSET_SHIFT      (0x00000002u)
#define CSL_EMIF_EIMSR_WRMSET_RESETVAL   (0x00000000u)

#define CSL_EMIF_EIMSR_LTMSET_MASK       (0x00000002u)
#define CSL_EMIF_EIMSR_LTMSET_SHIFT      (0x00000001u)
#define CSL_EMIF_EIMSR_LTMSET_RESETVAL   (0x00000000u)

#define CSL_EMIF_EIMSR_ATMSET_MASK       (0x00000001u)
#define CSL_EMIF_EIMSR_ATMSET_SHIFT      (0x00000000u)
#define CSL_EMIF_EIMSR_ATMSET_RESETVAL   (0x00000000u)

#define CSL_EMIF_EIMSR_RESETVAL          (0x00000000u)

/* EIMCR */

#define CSL_EMIF_EIMCR_WRMCLR_MASK       (0x0000003Cu)
#define CSL_EMIF_EIMCR_WRMCLR_SHIFT      (0x00000002u)
#define CSL_EMIF_EIMCR_WRMCLR_RESETVAL   (0x00000000u)

#define CSL_EMIF_EIMCR_LTMCLR_MASK       (0x00000002u)
#define CSL_EMIF_EIMCR_LTMCLR_SHIFT      (0x00000001u)
#define CSL_EMIF_EIMCR_LTMCLR_RESETVAL   (0x00000000u)

#define CSL_EMIF_EIMCR_ATMCLR_MASK       (0x00000001u)
#define CSL_EMIF_EIMCR_ATMCLR_SHIFT      (0x00000000u)
#define CSL_EMIF_EIMCR_ATMCLR_RESETVAL   (0x00000000u)

#define CSL_EMIF_EIMCR_RESETVAL          (0x00000000u)

/* IOCTRLR */

#define CSL_EMIF_IOCTRLR_IOCTRL_MASK     (0x0000FFFFu)
#define CSL_EMIF_IOCTRLR_IOCTRL_SHIFT    (0x00000000u)
#define CSL_EMIF_IOCTRLR_IOCTRL_RESETVAL (0x00000000u)

#define CSL_EMIF_IOCTRLR_RESETVAL        (0x00000000u)

/* IOSTATR */

#define CSL_EMIF_IOSTATR_IOSTAT_MASK     (0x0000000Fu)
#define CSL_EMIF_IOSTATR_IOSTAT_SHIFT    (0x00000000u)
#define CSL_EMIF_IOSTATR_IOSTAT_RESETVAL (0x00000000u)

#define CSL_EMIF_IOSTATR_RESETVAL        (0x00000000u)

/* NANDFCR */

#define CSL_EMIF_NANDFCR_CS5ECC_MASK     (0x00000800u)
#define CSL_EMIF_NANDFCR_CS5ECC_SHIFT    (0x0000000Bu)
#define CSL_EMIF_NANDFCR_CS5ECC_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS4ECC_MASK     (0x00000400u)
#define CSL_EMIF_NANDFCR_CS4ECC_SHIFT    (0x0000000Au)
#define CSL_EMIF_NANDFCR_CS4ECC_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS3ECC_MASK     (0x00000200u)
#define CSL_EMIF_NANDFCR_CS3ECC_SHIFT    (0x00000009u)
#define CSL_EMIF_NANDFCR_CS3ECC_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS2ECC_MASK     (0x00000100u)
#define CSL_EMIF_NANDFCR_CS2ECC_SHIFT    (0x00000008u)
#define CSL_EMIF_NANDFCR_CS2ECC_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS5NAND_MASK    (0x00000008u)
#define CSL_EMIF_NANDFCR_CS5NAND_SHIFT   (0x00000003u)
#define CSL_EMIF_NANDFCR_CS5NAND_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS4NAND_MASK    (0x00000004u)
#define CSL_EMIF_NANDFCR_CS4NAND_SHIFT   (0x00000002u)
#define CSL_EMIF_NANDFCR_CS4NAND_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS3NAND_MASK    (0x00000002u)
#define CSL_EMIF_NANDFCR_CS3NAND_SHIFT   (0x00000001u)
#define CSL_EMIF_NANDFCR_CS3NAND_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_CS2NAND_MASK    (0x00000001u)
#define CSL_EMIF_NANDFCR_CS2NAND_SHIFT   (0x00000000u)
#define CSL_EMIF_NANDFCR_CS2NAND_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFCR_RESETVAL        (0x00000000u)

/* NANDFSR */

#define CSL_EMIF_NANDFSR_WAITST_MASK     (0x0000000Fu)
#define CSL_EMIF_NANDFSR_WAITST_SHIFT    (0x00000000u)
#define CSL_EMIF_NANDFSR_WAITST_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDFSR_RESETVAL        (0x00000000u)

/* NANDF1ECC */

#define CSL_EMIF_NANDF1ECC_P2048O_MASK   (0x08000000u)
#define CSL_EMIF_NANDF1ECC_P2048O_SHIFT  (0x0000001Bu)
#define CSL_EMIF_NANDF1ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P1024O_MASK   (0x04000000u)
#define CSL_EMIF_NANDF1ECC_P1024O_SHIFT  (0x0000001Au)
#define CSL_EMIF_NANDF1ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P512O_MASK    (0x02000000u)
#define CSL_EMIF_NANDF1ECC_P512O_SHIFT   (0x00000019u)
#define CSL_EMIF_NANDF1ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P256O_MASK    (0x01000000u)
#define CSL_EMIF_NANDF1ECC_P256O_SHIFT   (0x00000018u)
#define CSL_EMIF_NANDF1ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P128O_MASK    (0x00800000u)
#define CSL_EMIF_NANDF1ECC_P128O_SHIFT   (0x00000017u)
#define CSL_EMIF_NANDF1ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P64O_MASK     (0x00400000u)
#define CSL_EMIF_NANDF1ECC_P64O_SHIFT    (0x00000016u)
#define CSL_EMIF_NANDF1ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P32O_MASK     (0x00200000u)
#define CSL_EMIF_NANDF1ECC_P32O_SHIFT    (0x00000015u)
#define CSL_EMIF_NANDF1ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P16O_MASK     (0x00100000u)
#define CSL_EMIF_NANDF1ECC_P16O_SHIFT    (0x00000014u)
#define CSL_EMIF_NANDF1ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P8O_MASK      (0x00080000u)
#define CSL_EMIF_NANDF1ECC_P8O_SHIFT     (0x00000013u)
#define CSL_EMIF_NANDF1ECC_P8O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P4O_MASK      (0x00040000u)
#define CSL_EMIF_NANDF1ECC_P4O_SHIFT     (0x00000012u)
#define CSL_EMIF_NANDF1ECC_P4O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P2O_MASK      (0x00020000u)
#define CSL_EMIF_NANDF1ECC_P2O_SHIFT     (0x00000011u)
#define CSL_EMIF_NANDF1ECC_P2O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P1O_MASK      (0x00010000u)
#define CSL_EMIF_NANDF1ECC_P1O_SHIFT     (0x00000010u)
#define CSL_EMIF_NANDF1ECC_P1O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P2048E_MASK   (0x00000800u)
#define CSL_EMIF_NANDF1ECC_P2048E_SHIFT  (0x0000000Bu)
#define CSL_EMIF_NANDF1ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P1024E_MASK   (0x00000400u)
#define CSL_EMIF_NANDF1ECC_P1024E_SHIFT  (0x0000000Au)
#define CSL_EMIF_NANDF1ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P512E_MASK    (0x00000200u)
#define CSL_EMIF_NANDF1ECC_P512E_SHIFT   (0x00000009u)
#define CSL_EMIF_NANDF1ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P256E_MASK    (0x00000100u)
#define CSL_EMIF_NANDF1ECC_P256E_SHIFT   (0x00000008u)
#define CSL_EMIF_NANDF1ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P128E_MASK    (0x00000080u)
#define CSL_EMIF_NANDF1ECC_P128E_SHIFT   (0x00000007u)
#define CSL_EMIF_NANDF1ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P64E_MASK     (0x00000040u)
#define CSL_EMIF_NANDF1ECC_P64E_SHIFT    (0x00000006u)
#define CSL_EMIF_NANDF1ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P32E_MASK     (0x00000020u)
#define CSL_EMIF_NANDF1ECC_P32E_SHIFT    (0x00000005u)
#define CSL_EMIF_NANDF1ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P16E_MASK     (0x00000010u)
#define CSL_EMIF_NANDF1ECC_P16E_SHIFT    (0x00000004u)
#define CSL_EMIF_NANDF1ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P8E_MASK      (0x00000008u)
#define CSL_EMIF_NANDF1ECC_P8E_SHIFT     (0x00000003u)
#define CSL_EMIF_NANDF1ECC_P8E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P4E_MASK      (0x00000004u)
#define CSL_EMIF_NANDF1ECC_P4E_SHIFT     (0x00000002u)
#define CSL_EMIF_NANDF1ECC_P4E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P2E_MASK      (0x00000002u)
#define CSL_EMIF_NANDF1ECC_P2E_SHIFT     (0x00000001u)
#define CSL_EMIF_NANDF1ECC_P2E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_P1E_MASK      (0x00000001u)
#define CSL_EMIF_NANDF1ECC_P1E_SHIFT     (0x00000000u)
#define CSL_EMIF_NANDF1ECC_P1E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF1ECC_RESETVAL      (0x00000000u)

/* NANDF2ECC */

#define CSL_EMIF_NANDF2ECC_P2048O_MASK   (0x08000000u)
#define CSL_EMIF_NANDF2ECC_P2048O_SHIFT  (0x0000001Bu)
#define CSL_EMIF_NANDF2ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P1024O_MASK   (0x04000000u)
#define CSL_EMIF_NANDF2ECC_P1024O_SHIFT  (0x0000001Au)
#define CSL_EMIF_NANDF2ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P512O_MASK    (0x02000000u)
#define CSL_EMIF_NANDF2ECC_P512O_SHIFT   (0x00000019u)
#define CSL_EMIF_NANDF2ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P256O_MASK    (0x01000000u)
#define CSL_EMIF_NANDF2ECC_P256O_SHIFT   (0x00000018u)
#define CSL_EMIF_NANDF2ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P128O_MASK    (0x00800000u)
#define CSL_EMIF_NANDF2ECC_P128O_SHIFT   (0x00000017u)
#define CSL_EMIF_NANDF2ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P64O_MASK     (0x00400000u)
#define CSL_EMIF_NANDF2ECC_P64O_SHIFT    (0x00000016u)
#define CSL_EMIF_NANDF2ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P32O_MASK     (0x00200000u)
#define CSL_EMIF_NANDF2ECC_P32O_SHIFT    (0x00000015u)
#define CSL_EMIF_NANDF2ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P16O_MASK     (0x00100000u)
#define CSL_EMIF_NANDF2ECC_P16O_SHIFT    (0x00000014u)
#define CSL_EMIF_NANDF2ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P8O_MASK      (0x00080000u)
#define CSL_EMIF_NANDF2ECC_P8O_SHIFT     (0x00000013u)
#define CSL_EMIF_NANDF2ECC_P8O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P4O_MASK      (0x00040000u)
#define CSL_EMIF_NANDF2ECC_P4O_SHIFT     (0x00000012u)
#define CSL_EMIF_NANDF2ECC_P4O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P2O_MASK      (0x00020000u)
#define CSL_EMIF_NANDF2ECC_P2O_SHIFT     (0x00000011u)
#define CSL_EMIF_NANDF2ECC_P2O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P1O_MASK      (0x00010000u)
#define CSL_EMIF_NANDF2ECC_P1O_SHIFT     (0x00000010u)
#define CSL_EMIF_NANDF2ECC_P1O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P2048E_MASK   (0x00000800u)
#define CSL_EMIF_NANDF2ECC_P2048E_SHIFT  (0x0000000Bu)
#define CSL_EMIF_NANDF2ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P1024E_MASK   (0x00000400u)
#define CSL_EMIF_NANDF2ECC_P1024E_SHIFT  (0x0000000Au)
#define CSL_EMIF_NANDF2ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P512E_MASK    (0x00000200u)
#define CSL_EMIF_NANDF2ECC_P512E_SHIFT   (0x00000009u)
#define CSL_EMIF_NANDF2ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P256E_MASK    (0x00000100u)
#define CSL_EMIF_NANDF2ECC_P256E_SHIFT   (0x00000008u)
#define CSL_EMIF_NANDF2ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P128E_MASK    (0x00000080u)
#define CSL_EMIF_NANDF2ECC_P128E_SHIFT   (0x00000007u)
#define CSL_EMIF_NANDF2ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P64E_MASK     (0x00000040u)
#define CSL_EMIF_NANDF2ECC_P64E_SHIFT    (0x00000006u)
#define CSL_EMIF_NANDF2ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P32E_MASK     (0x00000020u)
#define CSL_EMIF_NANDF2ECC_P32E_SHIFT    (0x00000005u)
#define CSL_EMIF_NANDF2ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P16E_MASK     (0x00000010u)
#define CSL_EMIF_NANDF2ECC_P16E_SHIFT    (0x00000004u)
#define CSL_EMIF_NANDF2ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P8E_MASK      (0x00000008u)
#define CSL_EMIF_NANDF2ECC_P8E_SHIFT     (0x00000003u)
#define CSL_EMIF_NANDF2ECC_P8E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P4E_MASK      (0x00000004u)
#define CSL_EMIF_NANDF2ECC_P4E_SHIFT     (0x00000002u)
#define CSL_EMIF_NANDF2ECC_P4E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P2E_MASK      (0x00000002u)
#define CSL_EMIF_NANDF2ECC_P2E_SHIFT     (0x00000001u)
#define CSL_EMIF_NANDF2ECC_P2E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_P1E_MASK      (0x00000001u)
#define CSL_EMIF_NANDF2ECC_P1E_SHIFT     (0x00000000u)
#define CSL_EMIF_NANDF2ECC_P1E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF2ECC_RESETVAL      (0x00000000u)

/* NANDF3ECC */

#define CSL_EMIF_NANDF3ECC_P2048O_MASK   (0x08000000u)
#define CSL_EMIF_NANDF3ECC_P2048O_SHIFT  (0x0000001Bu)
#define CSL_EMIF_NANDF3ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P1024O_MASK   (0x04000000u)
#define CSL_EMIF_NANDF3ECC_P1024O_SHIFT  (0x0000001Au)
#define CSL_EMIF_NANDF3ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P512O_MASK    (0x02000000u)
#define CSL_EMIF_NANDF3ECC_P512O_SHIFT   (0x00000019u)
#define CSL_EMIF_NANDF3ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P256O_MASK    (0x01000000u)
#define CSL_EMIF_NANDF3ECC_P256O_SHIFT   (0x00000018u)
#define CSL_EMIF_NANDF3ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P128O_MASK    (0x00800000u)
#define CSL_EMIF_NANDF3ECC_P128O_SHIFT   (0x00000017u)
#define CSL_EMIF_NANDF3ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P64O_MASK     (0x00400000u)
#define CSL_EMIF_NANDF3ECC_P64O_SHIFT    (0x00000016u)
#define CSL_EMIF_NANDF3ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P32O_MASK     (0x00200000u)
#define CSL_EMIF_NANDF3ECC_P32O_SHIFT    (0x00000015u)
#define CSL_EMIF_NANDF3ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P16O_MASK     (0x00100000u)
#define CSL_EMIF_NANDF3ECC_P16O_SHIFT    (0x00000014u)
#define CSL_EMIF_NANDF3ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P8O_MASK      (0x00080000u)
#define CSL_EMIF_NANDF3ECC_P8O_SHIFT     (0x00000013u)
#define CSL_EMIF_NANDF3ECC_P8O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P4O_MASK      (0x00040000u)
#define CSL_EMIF_NANDF3ECC_P4O_SHIFT     (0x00000012u)
#define CSL_EMIF_NANDF3ECC_P4O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P2O_MASK      (0x00020000u)
#define CSL_EMIF_NANDF3ECC_P2O_SHIFT     (0x00000011u)
#define CSL_EMIF_NANDF3ECC_P2O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P1O_MASK      (0x00010000u)
#define CSL_EMIF_NANDF3ECC_P1O_SHIFT     (0x00000010u)
#define CSL_EMIF_NANDF3ECC_P1O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P2048E_MASK   (0x00000800u)
#define CSL_EMIF_NANDF3ECC_P2048E_SHIFT  (0x0000000Bu)
#define CSL_EMIF_NANDF3ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P1024E_MASK   (0x00000400u)
#define CSL_EMIF_NANDF3ECC_P1024E_SHIFT  (0x0000000Au)
#define CSL_EMIF_NANDF3ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P512E_MASK    (0x00000200u)
#define CSL_EMIF_NANDF3ECC_P512E_SHIFT   (0x00000009u)
#define CSL_EMIF_NANDF3ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P256E_MASK    (0x00000100u)
#define CSL_EMIF_NANDF3ECC_P256E_SHIFT   (0x00000008u)
#define CSL_EMIF_NANDF3ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P128E_MASK    (0x00000080u)
#define CSL_EMIF_NANDF3ECC_P128E_SHIFT   (0x00000007u)
#define CSL_EMIF_NANDF3ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P64E_MASK     (0x00000040u)
#define CSL_EMIF_NANDF3ECC_P64E_SHIFT    (0x00000006u)
#define CSL_EMIF_NANDF3ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P32E_MASK     (0x00000020u)
#define CSL_EMIF_NANDF3ECC_P32E_SHIFT    (0x00000005u)
#define CSL_EMIF_NANDF3ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P16E_MASK     (0x00000010u)
#define CSL_EMIF_NANDF3ECC_P16E_SHIFT    (0x00000004u)
#define CSL_EMIF_NANDF3ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P8E_MASK      (0x00000008u)
#define CSL_EMIF_NANDF3ECC_P8E_SHIFT     (0x00000003u)
#define CSL_EMIF_NANDF3ECC_P8E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P4E_MASK      (0x00000004u)
#define CSL_EMIF_NANDF3ECC_P4E_SHIFT     (0x00000002u)
#define CSL_EMIF_NANDF3ECC_P4E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P2E_MASK      (0x00000002u)
#define CSL_EMIF_NANDF3ECC_P2E_SHIFT     (0x00000001u)
#define CSL_EMIF_NANDF3ECC_P2E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_P1E_MASK      (0x00000001u)
#define CSL_EMIF_NANDF3ECC_P1E_SHIFT     (0x00000000u)
#define CSL_EMIF_NANDF3ECC_P1E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF3ECC_RESETVAL      (0x00000000u)

/* NANDF4ECC */

#define CSL_EMIF_NANDF4ECC_P2048O_MASK   (0x08000000u)
#define CSL_EMIF_NANDF4ECC_P2048O_SHIFT  (0x0000001Bu)
#define CSL_EMIF_NANDF4ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P1024O_MASK   (0x04000000u)
#define CSL_EMIF_NANDF4ECC_P1024O_SHIFT  (0x0000001Au)
#define CSL_EMIF_NANDF4ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P512O_MASK    (0x02000000u)
#define CSL_EMIF_NANDF4ECC_P512O_SHIFT   (0x00000019u)
#define CSL_EMIF_NANDF4ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P256O_MASK    (0x01000000u)
#define CSL_EMIF_NANDF4ECC_P256O_SHIFT   (0x00000018u)
#define CSL_EMIF_NANDF4ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P128O_MASK    (0x00800000u)
#define CSL_EMIF_NANDF4ECC_P128O_SHIFT   (0x00000017u)
#define CSL_EMIF_NANDF4ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P64O_MASK     (0x00400000u)
#define CSL_EMIF_NANDF4ECC_P64O_SHIFT    (0x00000016u)
#define CSL_EMIF_NANDF4ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P32O_MASK     (0x00200000u)
#define CSL_EMIF_NANDF4ECC_P32O_SHIFT    (0x00000015u)
#define CSL_EMIF_NANDF4ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P16O_MASK     (0x00100000u)
#define CSL_EMIF_NANDF4ECC_P16O_SHIFT    (0x00000014u)
#define CSL_EMIF_NANDF4ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P8O_MASK      (0x00080000u)
#define CSL_EMIF_NANDF4ECC_P8O_SHIFT     (0x00000013u)
#define CSL_EMIF_NANDF4ECC_P8O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P4O_MASK      (0x00040000u)
#define CSL_EMIF_NANDF4ECC_P4O_SHIFT     (0x00000012u)
#define CSL_EMIF_NANDF4ECC_P4O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P2O_MASK      (0x00020000u)
#define CSL_EMIF_NANDF4ECC_P2O_SHIFT     (0x00000011u)
#define CSL_EMIF_NANDF4ECC_P2O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P1O_MASK      (0x00010000u)
#define CSL_EMIF_NANDF4ECC_P1O_SHIFT     (0x00000010u)
#define CSL_EMIF_NANDF4ECC_P1O_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P2048E_MASK   (0x00000800u)
#define CSL_EMIF_NANDF4ECC_P2048E_SHIFT  (0x0000000Bu)
#define CSL_EMIF_NANDF4ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P1024E_MASK   (0x00000400u)
#define CSL_EMIF_NANDF4ECC_P1024E_SHIFT  (0x0000000Au)
#define CSL_EMIF_NANDF4ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P512E_MASK    (0x00000200u)
#define CSL_EMIF_NANDF4ECC_P512E_SHIFT   (0x00000009u)
#define CSL_EMIF_NANDF4ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P256E_MASK    (0x00000100u)
#define CSL_EMIF_NANDF4ECC_P256E_SHIFT   (0x00000008u)
#define CSL_EMIF_NANDF4ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P128E_MASK    (0x00000080u)
#define CSL_EMIF_NANDF4ECC_P128E_SHIFT   (0x00000007u)
#define CSL_EMIF_NANDF4ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P64E_MASK     (0x00000040u)
#define CSL_EMIF_NANDF4ECC_P64E_SHIFT    (0x00000006u)
#define CSL_EMIF_NANDF4ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P32E_MASK     (0x00000020u)
#define CSL_EMIF_NANDF4ECC_P32E_SHIFT    (0x00000005u)
#define CSL_EMIF_NANDF4ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P16E_MASK     (0x00000010u)
#define CSL_EMIF_NANDF4ECC_P16E_SHIFT    (0x00000004u)
#define CSL_EMIF_NANDF4ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P8E_MASK      (0x00000008u)
#define CSL_EMIF_NANDF4ECC_P8E_SHIFT     (0x00000003u)
#define CSL_EMIF_NANDF4ECC_P8E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P4E_MASK      (0x00000004u)
#define CSL_EMIF_NANDF4ECC_P4E_SHIFT     (0x00000002u)
#define CSL_EMIF_NANDF4ECC_P4E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P2E_MASK      (0x00000002u)
#define CSL_EMIF_NANDF4ECC_P2E_SHIFT     (0x00000001u)
#define CSL_EMIF_NANDF4ECC_P2E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_P1E_MASK      (0x00000001u)
#define CSL_EMIF_NANDF4ECC_P1E_SHIFT     (0x00000000u)
#define CSL_EMIF_NANDF4ECC_P1E_RESETVAL  (0x00000000u)

#define CSL_EMIF_NANDF4ECC_RESETVAL      (0x00000000u)

/* IODFTECR */

#define CSL_EMIF_IODFTECR_TLEC_MASK      (0x0000FFFFu)
#define CSL_EMIF_IODFTECR_TLEC_SHIFT     (0x00000000u)
#define CSL_EMIF_IODFTECR_TLEC_RESETVAL  (0x00000000u)

#define CSL_EMIF_IODFTECR_RESETVAL       (0x00000000u)

/* IODFTGCR */

#define CSL_EMIF_IODFTGCR_MT_MASK        (0x00004000u)
#define CSL_EMIF_IODFTGCR_MT_SHIFT       (0x0000000Eu)
#define CSL_EMIF_IODFTGCR_MT_RESETVAL    (0x00000000u)

#define CSL_EMIF_IODFTGCR_OPGLD_MASK     (0x00001000u)
#define CSL_EMIF_IODFTGCR_OPGLD_SHIFT    (0x0000000Cu)
#define CSL_EMIF_IODFTGCR_OPGLD_RESETVAL (0x00000000u)

#define CSL_EMIF_IODFTGCR_MMS_MASK       (0x00000100u)
#define CSL_EMIF_IODFTGCR_MMS_SHIFT      (0x00000008u)
#define CSL_EMIF_IODFTGCR_MMS_RESETVAL   (0x00000000u)

#define CSL_EMIF_IODFTGCR_ESEL_MASK      (0x00000080u)
#define CSL_EMIF_IODFTGCR_ESEL_SHIFT     (0x00000007u)
#define CSL_EMIF_IODFTGCR_ESEL_RESETVAL  (0x00000001u)

#define CSL_EMIF_IODFTGCR_TOEN_MASK      (0x00000040u)
#define CSL_EMIF_IODFTGCR_TOEN_SHIFT     (0x00000006u)
#define CSL_EMIF_IODFTGCR_TOEN_RESETVAL  (0x00000000u)

#define CSL_EMIF_IODFTGCR_MC_MASK        (0x00000030u)
#define CSL_EMIF_IODFTGCR_MC_SHIFT       (0x00000004u)
#define CSL_EMIF_IODFTGCR_MC_RESETVAL    (0x00000001u)

#define CSL_EMIF_IODFTGCR_PC_MASK        (0x0000000Eu)
#define CSL_EMIF_IODFTGCR_PC_SHIFT       (0x00000001u)
#define CSL_EMIF_IODFTGCR_PC_RESETVAL    (0x00000000u)

#define CSL_EMIF_IODFTGCR_TM_MASK        (0x00000001u)
#define CSL_EMIF_IODFTGCR_TM_SHIFT       (0x00000000u)
#define CSL_EMIF_IODFTGCR_TM_RESETVAL    (0x00000001u)

#define CSL_EMIF_IODFTGCR_RESETVAL       (0x00000091u)

/* IODFTMRLR */

#define CSL_EMIF_IODFTMRLR_TLMR_MASK     (0xFFFFFFFFu)
#define CSL_EMIF_IODFTMRLR_TLMR_SHIFT    (0x00000000u)
#define CSL_EMIF_IODFTMRLR_TLMR_RESETVAL (0x00000000u)

#define CSL_EMIF_IODFTMRLR_RESETVAL      (0x00000000u)

/* IODFTMRMR */

#define CSL_EMIF_IODFTMRMR_TLMR_MASK     (0xFFFFFFFFu)
#define CSL_EMIF_IODFTMRMR_TLMR_SHIFT    (0x00000000u)
#define CSL_EMIF_IODFTMRMR_TLMR_RESETVAL (0x00000000u)

#define CSL_EMIF_IODFTMRMR_RESETVAL      (0x00000000u)

/* IODFTMRMSBR */

#define CSL_EMIF_IODFTMRMSBR_TLMR_MASK   (0xFFFFFFFFu)
#define CSL_EMIF_IODFTMRMSBR_TLMR_SHIFT  (0x00000000u)
#define CSL_EMIF_IODFTMRMSBR_TLMR_RESETVAL (0x00000000u)

#define CSL_EMIF_IODFTMRMSBR_RESETVAL    (0x00000000u)

/* MODRNR */

#define CSL_EMIF_MODRNR_RLNUM_MASK       (0x000000FFu)
#define CSL_EMIF_MODRNR_RLNUM_SHIFT      (0x00000000u)
#define CSL_EMIF_MODRNR_RLNUM_RESETVAL   (0x00000003u)

#define CSL_EMIF_MODRNR_RESETVAL         (0x00000003u)

#endif
